//
// NewMailNotify, based on FeedParser
//
// This will refresh the alert button
//
// $Id: class_NewMailNotify.js,v 1.0 2004/02/20 17:03:48 hodge Exp $

function NewMailNotify ()
{
    this.data = "";
    this.lines = new Array();
}

// findItems is responsible for breaking the
// whole line of data into individual things for
// the toolbar.  (things might be buttons, menus, or
// anything.  This function just seperates those items
// into an Array.  It doesn't interpret those lines.
// From reverse engineering the feed, the key seperators
// are control-T and control-U
NewMailNotify.prototype.findItems = function(toolbarLine)
{
    var offset = 0;
    var ItemStart = 0;
    var ItemEnd = 0;
    var fullLen = toolbarLine.length;
    var ToolBarItems = new Array();
    // find the ctrl_t
    // \x14 is Control-T, \x15 is Control-U
    while((offset+1) < fullLen)
    {
        ItemStart = toolbarLine.indexOf("\x14",offset);
        if(ItemStart == -1)
        {
            // we're out of Control-T's.  so we're done
            break;
        }
        ItemEnd = toolbarLine.indexOf("\x15", ItemStart);
        var len = ItemEnd - ItemStart;
        var str = toolbarLine.substr(ItemStart, len);
        ToolBarItems.push(str);
        offset = ItemEnd;
    }

    return ToolBarItems;
}

// parse is responsible for parsing the whole line
NewMailNotify.prototype.parse = function(fdata)
{
    var ToolBarObjects = new Array();
    var offline = false;

    // class_StreamListener calls parse with an empty fdata parameter
    // when the browser is offline and cannot get the yahoo feed
    // don't bother refreshing alert button
    if (fdata == "") {
        return;
    }

    //alert("Parsing!");
    this.data = fdata;
    this.lines = fdata.split("\n");
    var toolbarLine = this.lines[3];
    // now a single item in the toolbar is from CTRL-T to CTRL-U
    // so now we just find each of those...
    var ToolBarItems;

    ToolBarItems = this.findItems(toolbarLine);

    // now we need to find our alert button
    var i = 0;
    var numItems = ToolBarItems.length;

    for( i=0; i < numItems ; i++)
    {
        var item = ToolBarItems[i];
        // all items have this general layout:
        // Y! ^X <text> ^X TYPE ...
        // so first let's fetch the text
        
        var start = item.indexOf('\x18');
        start++;
        var end = item.indexOf('\x18',start);
        var text = item.substr(start,(end-start));
        
        // now find the TYPE.  this is always the first char after
        // the ^X... 
        var type = item.charAt(end+1);
        var typeTxt;
        
        // could be a button, menu, buttonmenu, editbox
        typeTxt = this.determineType(type);
        // now if this is a button, figure out which kind

        if(typeTxt == "menu")
        {
            start = end+3;
            var wholeMenu = item.substr(start);
            var menu = new Menu(text, wholeMenu);
            ToolBarObjects.push(menu);	
            
            // Do we have mail? if so let's alert the user, otherwise 
            // hide the alert in case it was displayed earlier but 
            // mail has been checked
            if (menu.title == "Alerts")
            {
				if (menu.items.length > 0) {
					var displayer = new CompanionDisplayer();
					var alertPopup = displayer.buildMenuPopup(menu.getItems());
					
					document.getElementById(_AlertButtonId).style.display = "";
					
					var AlertButtonMenu = document.getElementById(_AlertButtonId);

					// Replace the alert menu item
					try {
						// Try to replace the existing one
						AlertButtonMenu.replaceChild(alertPopup.childNodes[0], AlertButtonMenu.childNodes[0].childNodes[0]);
					} catch (e) {
						// Didn't work...
						try {
							// Add a new button
							AlertButtonMenu.childNodes[0].appendChild(alertPopup.childNodes[0]);
						} catch (e) {
							// Error refreshing alert button
						}						
					}
					
					// Replace the text for the alert menu item
					try {
						AlertButtonMenu.childNodes[0].childNodes[0].attributes.item(0).nodeValue = menu.getTxt();
					} catch (e) {
						// Do nothing
					}
				} else {
					document.getElementById(_AlertButtonId).style.display = "none";
				}
            } 
        }
    }
}

// determineType takes a character, and returns a string
// that represents what the item is supposed to be in the toolbar.
// ^B is a button
// ^C is a menu
// ^D is a button and a menu
NewMailNotify.prototype.determineType = function(txt)
{
    var code = txt.charCodeAt(0);
    switch(code)
    {
        case 2:
        {
            return "button";
        }
        case 3:
        {
            return "menu";
        }
        case 4:
        {
            return "buttonmenu";
        }
        case 7:
        {
            return "editbox";
        }
        case 131:
        {
            return "messenger";
        }
        default:
        {
            return "unknown";
        }
    }
}
